nftregistrar

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2023 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	NftRegistrarAPI = "nft-registrar"

	QueryRegistrarLabel              = "registrar"
	QueryResolverLabel               = "resolver"
	QueryAccountByDomainLabel        = "account-by-domain"
	QueryDomainByAccountLabel        = "domain-by-account"
	QueryDomainHistoryByAccountLabel = "domain-history-by-account"
	QueryExpiredLatestDomainLabel    = "expired-latest-domain"
	QueryTokenIDByDomainLabel        = "tokenid-by-domain"
	QuerySubdomainLabel              = "subdomain"
	QuerySubdomainsLabel             = "subdomains"
	QueryHashResultLabel             = "hash"
	QueryContractInfoLabel           = "contract-info"
	QueryNftInfoLabel                = "nft-info"
	QueryOwnerOfLabel                = "owner-of"
	QueryAllNftInfoLabel             = "all-nft-info"
	QueryAllOperatorsLabel           = "all-operators"
	QueryNumTokensLabel              = "num-tokens"
	QueryTokensLabel                 = "tokens"
	QueryAllTokensLabel              = "all-tokens"
	QueryApprovalLabel               = "approval"
	QueryApprovalsLabel              = "approvals"
	QueryMinterLabel                 = "minter"
)

Variables

This section is empty.

Functions

func ExecSetRegistrar

func ExecSetRegistrar(xnsContext *types.XnsContext) error

func ExecSetResolver

func ExecSetResolver(xnsContext *types.XnsContext) error

func ExecuteNftRegistrar

func ExecuteNftRegistrar(xnsContext *types.XnsContext, msg, amount string) (*xtypes.TxRes, error)

func NewNftRegistrarAccountByDomainQueryMsg

func NewNftRegistrarAccountByDomainQueryMsg(label, topDomain string) (string, error)

func NewNftRegistrarAllNftInfoQueryMsg

func NewNftRegistrarAllNftInfoQueryMsg(tokenID string, includeExpired interface{}) (string, error)

func NewNftRegistrarAllOperatorsQueryMsg

func NewNftRegistrarAllOperatorsQueryMsg(owner string, includeExpired, startAfter, limit interface{}) (string, error)

func NewNftRegistrarAlltokensQueryMsg

func NewNftRegistrarAlltokensQueryMsg(startAfter interface{}, limit interface{}) (string, error)

func NewNftRegistrarApprovalQueryMsg

func NewNftRegistrarApprovalQueryMsg(tokenID, spender string, includeExpired interface{}) (string, error)

func NewNftRegistrarApprovalsQueryMsg

func NewNftRegistrarApprovalsQueryMsg(tokenID string, includeExpired interface{}) (string, error)

func NewNftRegistrarApproveAllExecuteMsg

func NewNftRegistrarApproveAllExecuteMsg(granter, operator string, atHeight interface{}, atTime interface{}) (string, error)

func NewNftRegistrarApproveExecuteMsg

func NewNftRegistrarApproveExecuteMsg(granter, spender, tokenID string, atHeight interface{}, atTime interface{}) (string, error)

func NewNftRegistrarBurnExecuteMsg

func NewNftRegistrarBurnExecuteMsg(tokenID string) (string, error)

func NewNftRegistrarContractInfoQueryMsg

func NewNftRegistrarContractInfoQueryMsg() (string, error)

func NewNftRegistrarDomainByAccountQueryMsg

func NewNftRegistrarDomainByAccountQueryMsg(account string) (string, error)

func NewNftRegistrarDomainHistoryByAccountQueryMsg

func NewNftRegistrarDomainHistoryByAccountQueryMsg(account string) (string, error)

func NewNftRegistrarExpiredLatestDomainQueryMsg

func NewNftRegistrarExpiredLatestDomainQueryMsg(label, topDomain string) (string, error)

func NewNftRegistrarGetRegistrarQueryMsg

func NewNftRegistrarGetRegistrarQueryMsg() (string, error)

func NewNftRegistrarGetResolverQueryMsg

func NewNftRegistrarGetResolverQueryMsg() (string, error)

func NewNftRegistrarHashResultQueryMsg

func NewNftRegistrarHashResultQueryMsg(input string) (string, error)

func NewNftRegistrarMinterQueryMsg

func NewNftRegistrarMinterQueryMsg() (string, error)

func NewNftRegistrarNftInfoQueryMsg

func NewNftRegistrarNftInfoQueryMsg(tokenID string) (string, error)

func NewNftRegistrarNumTokensQueryMsg

func NewNftRegistrarNumTokensQueryMsg() (string, error)

func NewNftRegistrarOwnerOfQueryMsg

func NewNftRegistrarOwnerOfQueryMsg(tokenID string, includeExpired interface{}) (string, error)

func NewNftRegistrarRevokeAllExecuteMsg

func NewNftRegistrarRevokeAllExecuteMsg(granter, operator string) (string, error)

func NewNftRegistrarRevokeExecuteMsg

func NewNftRegistrarRevokeExecuteMsg(granter, spender, tokenID string) (string, error)

func NewNftRegistrarSendNftExecuteMsg

func NewNftRegistrarSendNftExecuteMsg(sender, contract, tokenID, msgBinary string) (string, error)

func NewNftRegistrarSetRegistrarExecuteMsg

func NewNftRegistrarSetRegistrarExecuteMsg(registrarAddress string) (string, error)

func NewNftRegistrarSetResolverExecuteMsg

func NewNftRegistrarSetResolverExecuteMsg(resolverAddress string) (string, error)

func NewNftRegistrarSubdomainQueryMsg

func NewNftRegistrarSubdomainQueryMsg(subdomainLabel, label, topDomain string) (string, error)

func NewNftRegistrarSubdomainsQueryMsg

func NewNftRegistrarSubdomainsQueryMsg(label, topDomain string) (string, error)

func NewNftRegistrarTokenIDByDomainQueryMsg

func NewNftRegistrarTokenIDByDomainQueryMsg(label, topDomain string) (string, error)

func NewNftRegistrarTokensQueryMsg

func NewNftRegistrarTokensQueryMsg(owner string, startAfter interface{}, limit interface{}) (string, error)

func NewNftRegistrarTransferNftExecuteMsg

func NewNftRegistrarTransferNftExecuteMsg(sender, recipient, tokenID string) (string, error)

func NewService

func NewService() service.Service

func Query

func Query(xnsContext *types.XnsContext, msg string) (*service.QueryResponse, error)

func QueryAccountByDomain

func QueryAccountByDomain(xnsContext *types.XnsContext, label, topDomain string) (*service.QueryResponse, error)

QueryAccountByDomain godoc @Summary Retrieve the account address by the domain @Description Get account address that has the retrieved domain @Tags NFT-Registrar @Accept json @Produce json @Param label path string true "domain name to retrieve" @Param top_domain path string true "top level domain" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/account-by-domain/{label}/{top-domain} [get]

func QueryAllNftInfo

func QueryAllNftInfo(xnsContext *types.XnsContext, tokenID string, includeExpired bool) (*service.QueryResponse, error)

QueryAllNftInfo godoc @Summary All NFT info of the token ID @Description Get the all NFT info by retrieving the token ID @Tags NFT-Registrar @Accept json @Produce json @Param token-id path string true "the NFT token ID" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/all-nft-info/{token-id} [get]

func QueryAllOperators

func QueryAllOperators(xnsContext *types.XnsContext, owner string, includeExpired bool, startAfter, limit string) (*service.QueryResponse, error)

QueryAllOperators godoc @Summary Operators info of the owner @Description Get operators info of the owner @Tags NFT-Registrar @Accept json @Produce json @Param owner path string true "the owner owns NFT" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/all-operators/{owner} [get]

func QueryAllTokens

func QueryAllTokens(xnsContext *types.XnsContext, startAfter, limit string) (*service.QueryResponse, error)

QueryAllTokens godoc @Summary All tokens in the contract @Description Get all tokens in the NFT registrar contract @Tags NFT-Registrar @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/all-tokens [get]

func QueryApproval

func QueryApproval(xnsContext *types.XnsContext, tokenID, spender string, includeExpired bool) (*service.QueryResponse, error)

QueryApproval godoc @Summary Approval of the token ID @Description Get approval of the token ID with the spender @Tags NFT-Registrar @Accept json @Produce json @Param token-id path string true "the NFT token ID" @Param spender path string true "the spender of the token ID" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/approval/{token-id}/{spender} [get]

func QueryApprovals

func QueryApprovals(xnsContext *types.XnsContext, tokenID string, includeExpired bool) (*service.QueryResponse, error)

QueryApprovals godoc @Summary Approvals of the token ID @Description Get approvals of the token ID @Tags NFT-Registrar @Accept json @Produce json @Param token-id path string true "the owner owns NFT" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/approvals/{token-id} [get]

func QueryContractInfo

func QueryContractInfo(xnsContext *types.XnsContext) (*service.QueryResponse, error)

QueryContractInfo godoc @Summary Get the contract info @Description Get the NFT registrar contract info @Tags NFT-Registrar @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/contract-info [get]

func QueryDomainByAccount

func QueryDomainByAccount(xnsContext *types.XnsContext, account string) (*service.QueryResponse, error)

QueryDomainbyAccount godoc @Summary Retrieve the domain by the account address @Description Get domain by retrieving account address @Tags NFT-Registrar @Accept json @Produce json @Param account path string true "account address to retrieve" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/domain-by-account/{account} [get]

func QueryDomainHistoryByAccount

func QueryDomainHistoryByAccount(xnsContext *types.XnsContext, account string) (*service.QueryResponse, error)

QueryHistoryDomainbyAccount godoc @Summary Retrieve the domain historyby the account address @Description Get domain history by retrieving account address @Tags NFT-Registrar @Accept json @Produce json @Param account path string true "account address to retrieve" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/domain-history-by-account/{account} [get]

func QueryExpiredLatestDomain

func QueryExpiredLatestDomain(xnsContext *types.XnsContext, label, topDomain string) (*service.QueryResponse, error)

QueryExpiredLatestDomain godoc @Summary Get domain info with expiration @Description Get domain info with expiration and the account who has the domain lastly @Tags NFT-Registrar @Accept json @Produce json @Param label path string true "domain name to retrieve" @Param top_domain path string true "top level domain" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/expired-latest-domain/{label}/{top-domain} [get]

func QueryHashResult

func QueryHashResult(xnsContext *types.XnsContext, input string) (*service.QueryResponse, error)

QueryHashResult godoc @Summary Get hash result @Description Get hash result for an input @Tags NFT-Registrar @Accept json @Produce json @Param input path string true "any input" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/hash/{input} [get]

func QueryMinter

func QueryMinter(xnsContext *types.XnsContext) (*service.QueryResponse, error)

QueryMinter godoc @Summary Minter of the contract @Description The Minter of the NFT registrar contract @Tags NFT-Registrar @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/minter [get]

func QueryNftInfo

func QueryNftInfo(xnsContext *types.XnsContext, tokenID string) (*service.QueryResponse, error)

QueryNftInfo godoc @Summary NFT info of the token ID @Description Get the NFT info by retrieving the token ID @Tags NFT-Registrar @Accept json @Produce json @Param token-id path string true "the NFT token ID" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/nft-info/{token-id} [get]

func QueryNumTokens

func QueryNumTokens(xnsContext *types.XnsContext) (*service.QueryResponse, error)

QueryNumTokens godoc @Summary The number of the all tokens @Description Get the number of the all tokens in the NFT registrar contract @Tags NFT-Registrar @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/num-tokens [get]

func QueryOwnerOf

func QueryOwnerOf(xnsContext *types.XnsContext, tokenID string, includeExpired bool) (*service.QueryResponse, error)

QueryOwnerOf godoc @Summary the owner info of the NFT @Description Get the owner info of the NFT by retrieving the token ID @Tags NFT-Registrar @Accept json @Produce json @Param token-id path string true "the NFT token ID" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/owner-of/{token-id} [get]

func QueryRegistrar

func QueryRegistrar(xnsContext *types.XnsContext) (*service.QueryResponse, error)

QueryRegistrar godoc @Summary Get registrar @Description Get connected address of the registrar contract @Tags NFT-Registrar @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/registrar [get]

func QueryResolver

func QueryResolver(xnsContext *types.XnsContext) (*service.QueryResponse, error)

QueryResolver godoc @Summary Get resolver @Description Get connected address of the resolver contract @Tags NFT-Registrar @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/resolver [get]

func QuerySubdomain

func QuerySubdomain(xnsContext *types.XnsContext, subdomainLabel, label, topDomain string) (*service.QueryResponse, error)

QuerySubdomain godoc @Summary Get subdomain data @Description Get subdomain mapped data @Tags NFT-Registrar @Accept json @Produce json @Param subdomain_label path string true "subdomain label" @Param label path string true "domain name to retrieve" @Param top_domain path string true "top level domain" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/subdomain/{subdomain-label}/{label}/{top-domain} [get]

func QuerySubdomains

func QuerySubdomains(xnsContext *types.XnsContext, label, topDomain string) (*service.QueryResponse, error)

QuerySubdomains godoc @Summary Get subdomains @Description Get subdomains list of the domain @Tags NFT-Registrar @Accept json @Produce json @Param label path string true "domain name to retrieve" @Param top_domain path string true "top level domain" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/subdomains/{label}/{top-domain} [get]

func QueryTokenIDByDomain

func QueryTokenIDByDomain(xnsContext *types.XnsContext, label, topDomain string) (*service.QueryResponse, error)

QueryTokenIDByDomain godoc @Summary Get token ID by domain @Description Get token ID by domain @Tags NFT-Registrar @Accept json @Produce json @Param label path string true "domain name to retrieve" @Param top_domain path string true "top level domain" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/tokenid-by-domain/{label}/{top-domain} [get]

func QueryTokens

func QueryTokens(xnsContext *types.XnsContext, owner, startAfter, limit string) (*service.QueryResponse, error)

QueryTokens godoc @Summary Tokens that the owner has @Description Get tokens that the owner has @Tags NFT-Registrar @Accept json @Produce json @Param owner path string true "the owner owns NFT" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /nft-registrar/tokens/{owner} [get]

Types

This section is empty.

Directories

Path Synopsis

Jump to