resolver

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2023 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	ResolverAPI = "resolver"

	QueryConfigLabel                 = "config"
	QueryDomainStateLabel            = "domain-state"
	QueryAccountStateLabel           = "account-state"
	QueryAccountFreeDomainStateLabel = "account-free-domain-state"
	QuerySubdomainLabel              = "subdomain"
)

Variables

This section is empty.

Functions

func ExecuteResolver

func ExecuteResolver(xnsContext *types.XnsContext, msg, amount string) (*xtypes.TxRes, error)

func NewRegistrarGetConfigQueryMsg

func NewRegistrarGetConfigQueryMsg() (string, error)

func NewResolverGetAccountFreeDomainStateMsg added in v0.0.2

func NewResolverGetAccountFreeDomainStateMsg(account string) (string, error)

func NewResolverGetAccountStateMsg

func NewResolverGetAccountStateMsg(account string) (string, error)

func NewResolverGetDomainStateMsg

func NewResolverGetDomainStateMsg(hashedLabel, topDomain string) (string, error)

func NewResolverGetSubdomainMsg

func NewResolverGetSubdomainMsg(hashedLabel, hashedSubdomainLabel string) (string, error)

func NewService

func NewService() service.Service

func Query

func Query(xnsContext *types.XnsContext, msg string) (*service.QueryResponse, error)

func QueryAccountFreeDomainState added in v0.0.2

func QueryAccountFreeDomainState(xnsContext *types.XnsContext, account string) (*service.QueryResponse, error)

QueryAccountFreeDomainState godoc @Summary XNS state for the free domain of the account @Description Get XNS state for the free domain of the account @Tags Resolver @Accept json @Produce json @Param account path string true "account address" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /resolver/account-free-domain-state/{account} [get]

func QueryAccountState

func QueryAccountState(xnsContext *types.XnsContext, account string) (*service.QueryResponse, error)

QueryAccountState godoc @Summary XNS state for the account @Description Get XNS state for the account @Tags Resolver @Accept json @Produce json @Param account path string true "account address" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /resolver/account-state/{account} [get]

func QueryConfig

func QueryConfig(xnsContext *types.XnsContext) (*service.QueryResponse, error)

QueryConfig godoc @Summary Config of the contract @Description Get configuration of the resolver contract @Tags Resolver @Accept json @Produce json @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /resolver/config [get]

func QueryDomainState

func QueryDomainState(xnsContext *types.XnsContext, hashedLabel, topDomain string) (*service.QueryResponse, error)

QueryDomainState godoc @Summary XNS state for the domain @Description Get XNS state for the domain @Tags Resolver @Accept json @Produce json @Param hashed_label path string true "hashed label" @Param top_domain path string true "top level domain" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /resolver/domain-state/{hashed-label}/{top-domain} [get]

func QuerySubdomain

func QuerySubdomain(xnsContext *types.XnsContext, hashedLabel, hashedSubdomainLabel string) (*service.QueryResponse, error)

QuerySubdomain godoc @Summary XNS state for a subdomain @Description Get XNS state for a subdomain @Tags Resolver @Accept json @Produce json @Param hashed_label path string true "hashed label" @Param hashed_subdomain_label path string true "hashed subdomain label" @Success 200 {object} service.QueryResponse @Failure 400 {object} service.QueryResponse @Router /resolver/subdomain/{hashed-label}/{hashed-subdomain-label} [get]

Types

This section is empty.

Directories

Path Synopsis

Jump to